/*
 * HFS (aka MAC) filesystem/handler for MorphOS/AmigaOS
 * Author: Marek 'March' Szyprowski <marek@amiga.pl>
 */

#ifndef __MACFS_HANDLER_PROTO_H
#define __MACFS_HANDLER_PROTO_H

/* dir */
LONG FillFIB (struct FSSuper *sb, ULONG cid, ULONG parid, struct FileInfoBlock *fib, BOOL dos64);
LONG GetParentDir(struct FSSuper *sb, ULONG cid, ULONG *res_parid);
LONG DirNextObj(struct FSSuper *sb, struct ExtFileLock *fl, struct FileInfoBlock *fib, BOOL dos64);

LONG CreateDirectory(struct FSSuper *sb, struct ExtFileLock *fl, UBYTE *path, LONG pathlen, BPTR *result);
LONG DeleteObject(struct FSSuper *sb, struct ExtFileLock *fl, UBYTE *path, LONG pathlen);
LONG RenameObject(struct FSSuper *sb, struct ExtFileLock *fl, UBYTE *path, LONG pathlen, struct ExtFileLock *dst_fl, UBYTE *dst_path, LONG dst_pathlen);

#if 0
LONG GetExtAttr(struct FSSuper *sb, struct ExtFileLock *fl, STRPTR path, LONG pathlen, struct ExtAttr *attrib);
LONG GetExtAttr(struct FSSuper *sb, struct ExtFileLock *fl, STRPTR path, LONG pathlen, struct ExtAttr *attrib);
#endif
LONG SetMacBootable(struct FSSuper *sb, struct ExtFileLock *fl);

/* file */
LONG FileOpen(struct FSSuper *sb, struct ExtFileLock *fl);
LONG FileRead(struct FSSuper *sb, struct ExtFileLock *fl, LONG bytes, APTR buffer, LONG *res);
LONG FileWrite(struct FSSuper *sb, struct ExtFileLock *fl, LONG bytes, APTR buffer, LONG *res);
LONG FileSeek(struct FSSuper *sb, struct ExtFileLock *fl, LONG offset, LONG mode, LONG *res);
LONG FileSetSize(struct FSSuper *sb, struct ExtFileLock *fl, LONG offset, LONG mode, LONG *res);
LONG CreateOpenFile(struct FSSuper *sb, struct ExtFileLock *fl, UBYTE *path, LONG pathlen, LONG action_type, struct FileHandle *fh);
LONG SetDate(struct FSSuper *sb, struct ExtFileLock *fl, STRPTR path, LONG pathlen, struct DateStamp *datestamp);

/* lock */
LONG LockObject(struct FSSuper *sb, ULONG cid, ULONG parid, LONG axs, BPTR *res);
LONG LockParent(struct FSSuper *sb, struct ExtFileLock *fl, LONG axs, BPTR *res);
LONG IsLockable(struct FSSuper *sb, ULONG cid, LONG mode);
LONG FreeLock(struct ExtFileLock *fl);
LONG LockByPath(struct FSSuper *sb, struct ExtFileLock *fl, UBYTE *name, LONG namelen, LONG access, BPTR *result);
void FreeLockStructures(struct FSSuper *sb);
LONG RestoreLockStructures(struct FSSuper *sb);

/* info */
void FillDiskInfo (struct InfoData *id);
LONG RenameDisk (struct FSSuper *sb, UBYTE *newname, LONG newname_len);
LONG FormatDisk(UBYTE *name, LONG namelen);

/* super */
LONG ReadSuper (struct FSSuper *s);
void FreeSuper(struct FSSuper *s);
LONG CompareSuper(struct FSSuper *s1, struct FSSuper *s2);

/* diskchange */
LONG FreeUnusedDisk(struct FSSuper *sb, struct FSSuper *prev);
void ProcessDiskChange(void);
void DoDiskInsert(void);
void DoDiskRemove(void);
void SendDiskChangePacket(ULONG action, APTR data);

/* diskio */
LONG InitFSSM(struct FileSysStartupMsg *fssm);
void FreeFSSM(void);
LONG InitDevice(LONG blocksize);
LONG GetDiskProtectionStatus(void);
LONG GetDiskGeometry(ULONG *res_sector_size, ULONG *res_total_sectors);
LONG UpdateDiskGeometry(void);
LONG DoRawRead (ULONG n, void *buff, ULONG blocksize);
LONG InitDiskHandler (struct FileSysStartupMsg *fssm, ULONG *ressigbit);
void CleanupDiskHandler(ULONG diskchgsig_bit);

/* packet.c */
void ProcessPackets(void);
void ReturnPacket(struct DosPacket *packet, LONG res1, LONG res2);
struct DosPacket *GetPacket(struct MsgPort *port);

#include "mac_inlines.h"

#endif

